@@ -116,7 +116,7 @@ class Identity:
         for i in sorted(self.attributes.keys()):
             c.append(i + self.attributes[i])
 
-        return abs(farmhash.hash64(''.join([
+        return abs(farmhash.fingerprint64(''.join([
             self.perspective,
             self.entity_type,
             ''.join(c)
